From 27f2cfdc57b75ea3994e31ad436464353d966cdd Mon Sep 17 00:00:00 2001
From: Timothy Pearson <kb9vqf@pearsoncomputing.net>
Date: Sun, 6 Nov 2011 02:32:00 -0600
Subject: Additional kde to tde renaming

---
 ark/Makefile.am                        |  2 +-
 kcalc/Makefile.am                      |  2 +-
 kcalc/knumber/tests/Makefile.am        |  2 +-
 kcharselect/Makefile.am                |  2 +-
 kcharselect/kcharselectdia.cc          |  2 +-
 kdelirc/irkick/Makefile.am             |  2 +-
 kdelirc/kdelirc/Makefile.am            |  2 +-
 kdelirc/profiles/klauncher.profile.xml |  4 ++--
 kdessh/Makefile.am                     |  4 ++--
 kdessh/kdessh.cpp                      | 12 ++++++------
 kdessh/sshdlg.cpp                      |  6 +++---
 kdessh/sshdlg.h                        |  2 +-
 kdf/Makefile.am                        |  4 ++--
 kdf/kconftest.cpp                      |  2 +-
 kedit/Makefile.am                      |  4 ++--
 kfloppy/Makefile.am                    |  2 +-
 kgpg/Makefile.am                       |  4 ++--
 khexedit/Makefile.am                   |  2 +-
 khexedit/parts/kbytesedit/README       |  2 +-
 khexedit/printdialogpage.h             |  2 +-
 khexedit/toplevel.cc                   |  2 +-
 kjots/Makefile.am                      |  2 +-
 klaptopdaemon/Makefile.am              | 10 +++++-----
 klaptopdaemon/acpi.cpp                 |  8 ++++----
 klaptopdaemon/apm.cpp                  | 16 ++++++++--------
 klaptopdaemon/daemondock.cpp           |  8 ++++----
 klaptopdaemon/sony.cpp                 |  8 ++++----
 kregexpeditor/Makefile.am              |  2 +-
 kregexpeditor/TODO                     |  4 ++--
 ktimer/Makefile.am                     |  4 ++--
 kwallet/Makefile.am                    |  2 +-
 superkaramba/src/Makefile.am           |  2 +-
 32 files changed, 66 insertions(+), 66 deletions(-)

diff --git a/ark/Makefile.am b/ark/Makefile.am
index b97b034..9761a28 100644
--- a/ark/Makefile.am
+++ b/ark/Makefile.am
@@ -5,7 +5,7 @@ SUBDIRS = pics
 
 # The binary name. Changed from kzip to ark
 bin_PROGRAMS =
-kdeinit_LTLIBRARIES = ark.la
+tdeinit_LTLIBRARIES = ark.la
 lib_LTLIBRARIES =
 
 ark_la_SOURCES = main.cpp arkapp.cpp mainwindow.cpp
diff --git a/kcalc/Makefile.am b/kcalc/Makefile.am
index 551d7d4..e72f732 100644
--- a/kcalc/Makefile.am
+++ b/kcalc/Makefile.am
@@ -4,7 +4,7 @@ SUBDIRS = knumber
 
 bin_PROGRAMS =
 lib_LTLIBRARIES =
-kdeinit_LTLIBRARIES = kcalc.la
+tdeinit_LTLIBRARIES = kcalc.la
 
 kcalc_la_SOURCES = kcalc.cpp kcalc_button.cpp kcalc_const_button.cpp \
 			kcalc_const_menu.cpp kcalc_core.cpp kcalcdisplay.cpp \
diff --git a/kcalc/knumber/tests/Makefile.am b/kcalc/knumber/tests/Makefile.am
index 3005a8d..be496fe 100644
--- a/kcalc/knumber/tests/Makefile.am
+++ b/kcalc/knumber/tests/Makefile.am
@@ -29,4 +29,4 @@ METASOURCES = AUTO
 
 knumbertest_SOURCES = knumbertest.cpp
 knumbertest_LDADD = ../libknumber.la $(LIB_QT) $(LIBGMP)
-knumbertest_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+knumbertest_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
diff --git a/kcharselect/Makefile.am b/kcharselect/Makefile.am
index ef1ab5d..f92a480 100644
--- a/kcharselect/Makefile.am
+++ b/kcharselect/Makefile.am
@@ -3,7 +3,7 @@ LDADD	= $(LIB_KFILE)
 bin_PROGRAMS = kcharselect
 
 kcharselect_SOURCES = kcharselectdia.cc main.cc
-kcharselect_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kcharselect_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 kcharselect_METASOURCES = kcharselectdia.moc
 
 updatedir = $(kde_datadir)/kconf_update
diff --git a/kcharselect/kcharselectdia.cc b/kcharselect/kcharselectdia.cc
index 00cb797..1e2f23d 100644
--- a/kcharselect/kcharselectdia.cc
+++ b/kcharselect/kcharselectdia.cc
@@ -33,7 +33,7 @@ KCharSelectDia::KCharSelectDia(TQWidget *parent,const char *name,
 
   grid = new TQGridLayout( mainWidget, 3, 4, KDialog::marginHint(), KDialog::spacingHint() );
 
-  // Add character selection widget from library kdeui
+  // Add character selection widget from library tdeui
   charSelect = new KCharSelect(mainWidget,"",vFont,vChr,_tableNum);
   charSelect->resize(charSelect->tqsizeHint());
   connect(charSelect,TQT_SIGNAL(highlighted(const TQChar &)),
diff --git a/kdelirc/irkick/Makefile.am b/kdelirc/irkick/Makefile.am
index 5479ac1..eb7f6d8 100644
--- a/kdelirc/irkick/Makefile.am
+++ b/kdelirc/irkick/Makefile.am
@@ -3,7 +3,7 @@ SUBDIRS = icons
 bin_PROGRAMS =
 lib_LTLIBRARIES =
 noinst_LTLIBRARIES = libirkick_common.la
-kdeinit_LTLIBRARIES = irkick.la
+tdeinit_LTLIBRARIES = irkick.la
 
 CLEANFILES = dummy.cpp
 
diff --git a/kdelirc/kdelirc/Makefile.am b/kdelirc/kdelirc/Makefile.am
index 1c65118..e4951ef 100644
--- a/kdelirc/kdelirc/Makefile.am
+++ b/kdelirc/kdelirc/Makefile.am
@@ -34,7 +34,7 @@ INCLUDES = $(all_includes)
 METASOURCES = AUTO
 
 # the library search path. 
-libkdelirc_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+libkdelirc_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 
 # Uncomment the following two lines if you add a ui.rc file for your application to make use of
 # KDE´s XML GUI builing
diff --git a/kdelirc/profiles/klauncher.profile.xml b/kdelirc/profiles/klauncher.profile.xml
index 87f9035..d5fa6f0 100644
--- a/kdelirc/profiles/klauncher.profile.xml
+++ b/kdelirc/profiles/klauncher.profile.xml
@@ -3,13 +3,13 @@
 <profile id="klauncher">
 	<name>KDE Program Launcher</name>
 	<author>Gav Wood</author>
-	<action objid="default" prototype="void kdeinit_exec(QString, QStringList)" repeat="0" autostart="0">
+	<action objid="default" prototype="void tdeinit_exec(QString, QStringList)" repeat="0" autostart="0">
 		<name>Execute</name>
 		<comment>Runs a program or script</comment>
 		<argument type=TQSTRING_OBJECT_NAME_STRING><comment>The executable name and path of the program or script to run</comment></argument>
 		<argument type=TQSTRINGLIST_OBJECT_NAME_STRING><comment>Parameters for the program or script</comment></argument>
 	</action>
-	<action objid="default" prototype="void kdeinit_exec_wait(QString, QStringList)" repeat="0" autostart="0">
+	<action objid="default" prototype="void tdeinit_exec_wait(QString, QStringList)" repeat="0" autostart="0">
 		<name>Execute and Wait</name>
 		<comment>Runs a program or script and waits for it to finish</comment>
 		<argument type=TQSTRING_OBJECT_NAME_STRING><comment>The executable name and path of the program or script to run</comment></argument>
diff --git a/kdessh/Makefile.am b/kdessh/Makefile.am
index 184bb86..09a20df 100644
--- a/kdessh/Makefile.am
+++ b/kdessh/Makefile.am
@@ -6,8 +6,8 @@ INCLUDES= $(all_includes)
 ## kdessh
 bin_PROGRAMS = 	kdessh
 kdessh_SOURCES = kdessh.cpp sshdlg.cpp
-kdessh_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
-kdessh_LDADD   = $(LIB_KDEUI) -lkdesu
+kdessh_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
+kdessh_LDADD   = $(LIB_KDEUI) -ltdesu
 kdessh_METASOURCES =  AUTO
 noinst_HEADERS = sshdlg.h
 
diff --git a/kdessh/sshdlg.h b/kdessh/sshdlg.h
index 644662f..cb77b36 100644
--- a/kdessh/sshdlg.h
+++ b/kdessh/sshdlg.h
@@ -2,7 +2,7 @@
  *
  * $Id$
  *
- * This file is part of the KDE project, module kdesu.
+ * This file is part of the KDE project, module tdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
  */
 
diff --git a/kdf/Makefile.am b/kdf/Makefile.am
index d524942..e330362 100644
--- a/kdf/Makefile.am
+++ b/kdf/Makefile.am
@@ -9,11 +9,11 @@ libkdf_common_la_SOURCES = kdfwidget.cpp kdfconfig.cpp mntconfig.cpp disklist.cp
 	disks.cpp listview.cpp optiondialog.cpp stdoption.cpp
 
 kdf_SOURCES = kdf.cpp 
-kdf_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kdf_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 kdf_LDADD = libkdf_common.la $(LIB_KFILE)
 
 kwikdisk_SOURCES = kwikdisk.cpp 
-kwikdisk_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kwikdisk_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 kwikdisk_LDADD = libkdf_common.la $(LIB_KFILE)
 
 kde_module_LTLIBRARIES = kcm_kdf.la
diff --git a/kdf/kconftest.cpp b/kdf/kconftest.cpp
index 7c0d0a9..9d9d5d3 100644
--- a/kdf/kconftest.cpp
+++ b/kdf/kconftest.cpp
@@ -27,7 +27,7 @@
 
 
 /* compile with
-* gcc  -I$TQTDIR/include -I$KDEDIR/include   -L/opt/kde/lib -L/usr/X11R6/lib -lkfm -lkdeui -lkdecore -lqt -lX11 -lXext -fno-rtti kconftest.cpp                
+* gcc  -I$TQTDIR/include -I$KDEDIR/include   -L/opt/kde/lib -L/usr/X11R6/lib -lkfm -ltdeui -ltdecore -lqt -lX11 -lXext -fno-rtti kconftest.cpp                
 */
 
 
diff --git a/kedit/Makefile.am b/kedit/Makefile.am
index 6870eb6..353b3d6 100644
--- a/kedit/Makefile.am
+++ b/kedit/Makefile.am
@@ -9,10 +9,10 @@ INCLUDES = $(all_includes)
 
 bin_PROGRAMS =
 lib_LTLIBRARIES =
-kdeinit_LTLIBRARIES = kedit.la
+tdeinit_LTLIBRARIES = kedit.la
 
 kedit_la_SOURCES = kedit.cpp ktextfiledlg.cpp misc.ui color.ui prefs.kcfgc
-kedit_la_LIBADD = -lkdeprint $(LIB_KFILE)
+kedit_la_LIBADD = -ltdeprint $(LIB_KFILE)
 kedit_la_LDFLAGS = -module -avoid-version $(KDE_PLUGIN) $(all_libraries)
 
 noinst_HEADERS = kedit.h ktextfiledlg.h\
diff --git a/kfloppy/Makefile.am b/kfloppy/Makefile.am
index c034214..935f1b2 100644
--- a/kfloppy/Makefile.am
+++ b/kfloppy/Makefile.am
@@ -1,4 +1,4 @@
-kfloppy_LDFLAGS	= $(all_libraries)  $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kfloppy_LDFLAGS	= $(all_libraries)  $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 kfloppy_LDADD =  $(LIB_KDEUI) -lm
 INCLUDES =	$(all_includes)
 
diff --git a/kgpg/Makefile.am b/kgpg/Makefile.am
index 0753c31..ba303dd 100644
--- a/kgpg/Makefile.am
+++ b/kgpg/Makefile.am
@@ -11,7 +11,7 @@ kgpg_SOURCES = kgpgoptions.cpp listkeys.cpp popuppublic.cpp kgpgview.cpp \
 		keyproperties.ui conf_encryption.ui conf_decryption.ui conf_gpg.ui dcopiface.skel \
 		keyinfowidget.cpp groupedit.ui kgpgrevokewidget.ui newkey.ui adduid.ui 	keyexport.ui \
 		sourceselect.ui kgpgsettings.kcfgc conf_servers.ui conf_ui2.ui conf_misc.ui
-kgpg_LDADD   =  $(LIB_KIO) $(LIB_KABC) -lkutils -lkdeprint
+kgpg_LDADD   =  $(LIB_KIO) $(LIB_KABC) -lkutils -ltdeprint
 
 pics_DATA= kgpg_anim.gif kgpg_docked.png  kgpg_docked.gif kgpg_blank.png  kgpg_fill.png
 picsdir=$(kde_datadir)/kgpg/pics
@@ -28,7 +28,7 @@ kde_kcfg_DATA = kgpg.kcfg
 METASOURCES = AUTO
 
 # the library search path.
-kgpg_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kgpg_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 
 appsdir = $(kde_datadir)/kgpg
 apps_DATA = kgpg.rc listkeys.rc tips
diff --git a/khexedit/Makefile.am b/khexedit/Makefile.am
index 47f3e60..973e352 100644
--- a/khexedit/Makefile.am
+++ b/khexedit/Makefile.am
@@ -20,7 +20,7 @@ draglabel.h progress.h hexeditstate.h chartabledialog.h hexdrag.h \
 exportdialog.h fileinfodialog.h converterdialog.h listview.h searchbar.h
 
 khexedit_METASOURCES = AUTO
-khexedit_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+khexedit_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 khexedit_LDADD = $(LIB_KIO) $(LIB_KDEPRINT)
 
 xdg_apps_DATA = khexedit.desktop
diff --git a/khexedit/parts/kbytesedit/README b/khexedit/parts/kbytesedit/README
index e3aa164..d6d2948 100644
--- a/khexedit/parts/kbytesedit/README
+++ b/khexedit/parts/kbytesedit/README
@@ -20,4 +20,4 @@ Installs the .desktop file describing the service and the module library.
 
 usage:
 ------
-Only official known usage is by KPilot (kdepim/kpilot) for now.
\ No newline at end of file
+Only official known usage is by KPilot (tdepim/kpilot) for now.
\ No newline at end of file
diff --git a/khexedit/printdialogpage.h b/khexedit/printdialogpage.h
index 1ad0ee4..73c3714 100644
--- a/khexedit/printdialogpage.h
+++ b/khexedit/printdialogpage.h
@@ -27,7 +27,7 @@ class TQComboBox;
 class TQLabel;
 class TQSpinBox;
 
-#include <kdeprint/kprintdialogpage.h>
+#include <tdeprint/kprintdialogpage.h>
 #include <ksimpleconfig.h>
 
 class LayoutDialogPage : public KPrintDialogPage
diff --git a/khexedit/toplevel.cc b/khexedit/toplevel.cc
index 7ac6a9a..d4aa185 100644
--- a/khexedit/toplevel.cc
+++ b/khexedit/toplevel.cc
@@ -376,7 +376,7 @@ void KHexEdit::initialize( bool openFiles )
 
   if ( openFiles && editor()->openFile() != SDisplayMisc::none )
   {
-    // Code modified from kdelibs/kdeui/kactionclasses.cpp KRecentFilesAction::loadEntries
+    // Code modified from kdelibs/tdeui/kactionclasses.cpp KRecentFilesAction::loadEntries
       
     KConfig* config = kapp->config();
 
diff --git a/kjots/Makefile.am b/kjots/Makefile.am
index 0389a69..453af81 100644
--- a/kjots/Makefile.am
+++ b/kjots/Makefile.am
@@ -1,5 +1,5 @@
 INCLUDES = $(all_includes)
-AM_LDFLAGS   = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+AM_LDFLAGS   = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 LDADD =  $(LIB_KFILE) $(LIB_KDEPRINT)
 
 bin_PROGRAMS = kjots
diff --git a/klaptopdaemon/Makefile.am b/klaptopdaemon/Makefile.am
index f36a324..9d755ed 100644
--- a/klaptopdaemon/Makefile.am
+++ b/klaptopdaemon/Makefile.am
@@ -4,30 +4,30 @@ lib_LTLIBRARIES = libkcmlaptop.la
 SUBDIRS = pics applnk
 
 libkcmlaptop_la_SOURCES = portable.cpp smapidev.c daemon_state.cpp wake_laptop.cpp krichtextlabel.cpp
-libkcmlaptop_la_LDFLAGS = $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+libkcmlaptop_la_LDFLAGS = $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 libkcmlaptop_la_LIBADD  = $(LIB_KDEUI) 
 
 MESSAGE_SOURCES = laptop_daemon.cpp kpcmcia.cpp xautolock.cc kpcmciainfo.cpp daemondock.cpp xautolock_diy.c xautolock_engine.c
 kded_klaptopdaemon_la_SOURCES = $(MESSAGE_SOURCES) laptop_daemon.skel  
-kded_klaptopdaemon_la_LDFLAGS = $(all_libraries) -module -avoid-version  -lXtst $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kded_klaptopdaemon_la_LDFLAGS = $(all_libraries) -module -avoid-version  -lXtst $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 kded_klaptopdaemon_la_LIBADD   = $(LIB_KDEUI) $(LIB_XSS) libkcmlaptop.la
 
 klaptop_acpi_helper_SOURCES = acpi_helper.cpp
 klaptop_acpi_helper_LDADD = $(LIB_QT)
 
 klaptop_check_SOURCES = laptop_check.cpp 
-klaptop_check_LDFLAGS = $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+klaptop_check_LDFLAGS = $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 klaptop_check_LDADD = $(LIB_KFILE) $(LIB_KDEUI) libkcmlaptop.la
 
 kcm_laptop_la_SOURCES = battery.cpp main.cpp pcmcia.cpp power.cpp warning.cpp \
 	acpi.cpp sony.cpp profile.cpp buttons.cpp apm.cpp  
-kcm_laptop_la_LDFLAGS  = $(all_libraries) $(KDE_PLUGIN) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -module
+kcm_laptop_la_LDFLAGS  = $(all_libraries) $(KDE_PLUGIN) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -module
 kcm_laptop_la_LIBADD = $(LIB_KFILE) $(LIB_KDEUI) libkcmlaptop.la
 kcm_laptop_la_COMPILE_FIRST = crcresult.h
 
 AM_CPPFLAGS = $(all_includes)
 
-AM_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+AM_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 
 KDE_OPTIONS = nofinal
 
diff --git a/klaptopdaemon/acpi.cpp b/klaptopdaemon/acpi.cpp
index 3fc436a..44c1822 100644
--- a/klaptopdaemon/acpi.cpp
+++ b/klaptopdaemon/acpi.cpp
@@ -166,8 +166,8 @@ void AcpiConfig::setupHelper()
 	TQString helper = KStandardDirs::findExe("klaptop_acpi_helper");
 	checkcrc(TQFile::encodeName(helper), len, crc);
 
-	TQString kdesu = KStandardDirs::findExe("kdesu");
-	if (!kdesu.isEmpty()) {
+	TQString tdesu = KStandardDirs::findExe("tdesu");
+	if (!tdesu.isEmpty()) {
 		int rc = KMessageBox::warningContinueCancel(0,
 				i18n("You will need to supply a root password "
 					"to allow the privileges of the klaptop_acpi_helper to change."),
@@ -175,14 +175,14 @@ void AcpiConfig::setupHelper()
 				"");
 		if (rc == KMessageBox::Continue) {
 			KProcess proc;
-			proc << kdesu;
+			proc << tdesu;
 			proc << "-u";
 			proc << "root";
 			proc <<  "dpkg-statoverride --update --add root root 6755 "+helper;
 			proc.start(KProcess::Block);	// run it sync so has_acpi below sees the results
 		}
 	} else {
-		KMessageBox::sorry(0, i18n("The ACPI helper cannot be enabled because kdesu cannot be found.  Please make sure that it is installed correctly."),
+		KMessageBox::sorry(0, i18n("The ACPI helper cannot be enabled because tdesu cannot be found.  Please make sure that it is installed correctly."),
 				i18n("KLaptopDaemon"));
 	}
 	laptop_portable::acpi_set_mask(enablestandby, enablesuspend, enablehibernate, enableperformance, enablethrottle);
diff --git a/klaptopdaemon/apm.cpp b/klaptopdaemon/apm.cpp
index e92dfc4..3869457 100644
--- a/klaptopdaemon/apm.cpp
+++ b/klaptopdaemon/apm.cpp
@@ -154,8 +154,8 @@ ApmConfig::~ApmConfig()
 
 void ApmConfig::setupHelper()
 {
-	TQString kdesu = KStandardDirs::findExe("kdesu");
-	if (!kdesu.isEmpty()) {
+	TQString tdesu = KStandardDirs::findExe("tdesu");
+	if (!tdesu.isEmpty()) {
 		int rc = KMessageBox::warningContinueCancel(0,
 				i18n("You will need to supply a root password "
 					"to allow the privileges of the %1 application to change.").tqarg(apm_name),
@@ -163,14 +163,14 @@ void ApmConfig::setupHelper()
 				"");
 		if (rc == KMessageBox::Continue) {
 			KProcess proc;
-			proc << kdesu;
+			proc << tdesu;
 			proc << "-u";
 			proc << "root";
 			proc <<  TQString("dpkg-statoverride --update --add root root 6755 ")+apm_name;
 			proc.start(KProcess::Block);	// run it sync so has_apm below sees the results
 		}
 	} else {
-		KMessageBox::sorry(0, i18n("%1 cannot be enabled because kdesu cannot be found.  Please make sure that it is installed correctly.").tqarg(TQString(apm_name)),
+		KMessageBox::sorry(0, i18n("%1 cannot be enabled because tdesu cannot be found.  Please make sure that it is installed correctly.").tqarg(TQString(apm_name)),
 				i18n("KLaptopDaemon"));
 	}
 	laptop_portable::apm_set_mask(enablestandby, enablesuspend);
@@ -188,8 +188,8 @@ void ApmConfig::setupHelper2()	// we use the acpi helper to do software suspend
 	TQString helper = KStandardDirs::findExe("klaptop_acpi_helper");
 	checkcrc(helper.latin1(), len, crc);
 
-	TQString kdesu = KStandardDirs::findExe("kdesu");
-	if (!kdesu.isEmpty()) {
+	TQString tdesu = KStandardDirs::findExe("tdesu");
+	if (!tdesu.isEmpty()) {
 		int rc = KMessageBox::warningContinueCancel(0,
 				i18n("You will need to supply a root password "
 					"to allow the privileges of the klaptop_acpi_helper to change."),
@@ -197,14 +197,14 @@ void ApmConfig::setupHelper2()	// we use the acpi helper to do software suspend
 				"");
 		if (rc == KMessageBox::Continue) {
 			KProcess proc;
-			proc << kdesu;
+			proc << tdesu;
 			proc << "-u";
 			proc << "root";
 			proc <<  "dpkg-statoverride --update --add root root 6755 "+helper;
 			proc.start(KProcess::Block);	// run it sync so has_acpi below sees the results
 		}
 	} else {
-		KMessageBox::sorry(0, i18n("The Software Suspend helper cannot be enabled because kdesu cannot be found.  Please make sure that it is installed correctly."),
+		KMessageBox::sorry(0, i18n("The Software Suspend helper cannot be enabled because tdesu cannot be found.  Please make sure that it is installed correctly."),
 				i18n("KLaptopDaemon"));
 	}
 	laptop_portable::software_suspend_set_mask(enablesoftwaresuspend);
diff --git a/klaptopdaemon/daemondock.cpp b/klaptopdaemon/daemondock.cpp
index c5c0a58..7c948b7 100644
--- a/klaptopdaemon/daemondock.cpp
+++ b/klaptopdaemon/daemondock.cpp
@@ -233,8 +233,8 @@ laptop_dock::invokeBrightness()
 
 void laptop_dock::slotGoRoot(int /*id*/) {
 #ifdef NOTDEF
-	TQString kdesu = KStandardDirs::findExe("kdesu");
-	if (!kdesu.isEmpty()) {
+	TQString tdesu = KStandardDirs::findExe("tdesu");
+	if (!tdesu.isEmpty()) {
 		int rc = KMessageBox::warningContinueCancel(0,
 				i18n("You will need to supply a root password "
 					"to allow KLaptopDaemon to restart "
@@ -246,7 +246,7 @@ void laptop_dock::slotGoRoot(int /*id*/) {
 		if (rc == KMessageBox::Continue) {
 			KProcess *_rootProcess;
 			_rootProcess = new KProcess;
-			*_rootProcess << kdesu;
+			*_rootProcess << tdesu;
 			*_rootProcess << "-u";
 			*_rootProcess << "root";
 			//*_rootProcess << "--nonewdcop";
@@ -257,7 +257,7 @@ void laptop_dock::slotGoRoot(int /*id*/) {
 			// We should disable this menu item here now.
 		}
 	} else {
-		KMessageBox::sorry(0, i18n("PCMCIA cannot be enabled since kdesu cannot be found. Please make sure that it is installed correctly."),
+		KMessageBox::sorry(0, i18n("PCMCIA cannot be enabled since tdesu cannot be found. Please make sure that it is installed correctly."),
 				i18n("KLaptopDaemon"));
 	}
 #else
diff --git a/klaptopdaemon/sony.cpp b/klaptopdaemon/sony.cpp
index 497a566..689b9d0 100644
--- a/klaptopdaemon/sony.cpp
+++ b/klaptopdaemon/sony.cpp
@@ -107,8 +107,8 @@ SonyConfig::SonyConfig(TQWidget * parent, const char *name)
 
 void SonyConfig::setupHelper()
 {
-	TQString kdesu = KStandardDirs::findExe("kdesu");
-	if (!kdesu.isEmpty()) {
+	TQString tdesu = KStandardDirs::findExe("tdesu");
+	if (!tdesu.isEmpty()) {
 		int rc = KMessageBox::warningContinueCancel(0,
 				i18n("You will need to supply a root password "
 					"to allow the protections of /dev/sonypi to be changed."),
@@ -116,14 +116,14 @@ void SonyConfig::setupHelper()
 				"");
 		if (rc == KMessageBox::Continue) {
 			KProcess proc;
-			proc << kdesu;
+			proc << tdesu;
 			proc << "-u";
 			proc << "root";
 			proc <<  "chmod +r /dev/sonypi";
 			proc.start(KProcess::Block);	// run it sync so has_acpi below sees the results
 		}
 	} else {
-		KMessageBox::sorry(0, i18n("The /dev/sonypi protections cannot be changed because kdesu cannot be found.  Please make sure that it is installed correctly."),
+		KMessageBox::sorry(0, i18n("The /dev/sonypi protections cannot be changed because tdesu cannot be found.  Please make sure that it is installed correctly."),
 				i18n("KLaptopDaemon"));
 	}
     	bool enable = ::access("/dev/sonypi", R_OK) == 0;
diff --git a/kregexpeditor/Makefile.am b/kregexpeditor/Makefile.am
index 9a12b31..f7118bb 100644
--- a/kregexpeditor/Makefile.am
+++ b/kregexpeditor/Makefile.am
@@ -46,7 +46,7 @@ libkregexpeditorgui_la_LIBADD = libkregexpeditorcommon.la
 
 bin_PROGRAMS = kregexpeditor
 kregexpeditor_SOURCES = main.cpp
-kregexpeditor_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kregexpeditor_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 kregexpeditor_LDADD =  libkregexpeditorcommon.la $(LIB_KIO)
 kregexpeditor_INCLUDES =  $(all_includes)
 
diff --git a/kregexpeditor/TODO b/kregexpeditor/TODO
index d8c492b..7ee9a13 100644
--- a/kregexpeditor/TODO
+++ b/kregexpeditor/TODO
@@ -31,14 +31,14 @@ KodeKnight
 kdeadmin
 kdebase
 kdeedu
-kdegames
+tdegames
 kdegraphics
 kdeinstaller
 kdelibs
 kdemultimedia
 kdenetwork
 kdenonbeta
-kdepim
+tdepim
 kdesdk
 kdetoys
 kfte
diff --git a/ktimer/Makefile.am b/ktimer/Makefile.am
index bad9286..77b6319 100644
--- a/ktimer/Makefile.am
+++ b/ktimer/Makefile.am
@@ -1,5 +1,5 @@
 INCLUDES = $(all_includes)
-AM_LDFLAGS	= $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+AM_LDFLAGS	= $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 LDADD =  $(LIB_KDEUI) $(LIB_KFILE)
 
 bin_PROGRAMS = ktimer
@@ -19,6 +19,6 @@ messages: rc.cpp
 
 
 srcdoc:
-	kdoc -a -p -H -d $$HOME/web/src/ktimer ktimer *.h -lkdecore -lkdeui -lqt
+	kdoc -a -p -H -d $$HOME/web/src/ktimer ktimer *.h -ltdecore -ltdeui -lqt
 
 
diff --git a/kwallet/Makefile.am b/kwallet/Makefile.am
index 7324ef2..731f9c4 100644
--- a/kwallet/Makefile.am
+++ b/kwallet/Makefile.am
@@ -7,7 +7,7 @@ kwalletmanager_SOURCES = walletwidget.ui kwalletmanager.cpp \
 			kwalletmanager.skel main.cpp kwalletpopup.cpp \
 			kwalleteditor.cpp kwmapeditor.cpp allyourbase.cpp \
 			kbetterthankdialogbase.ui
-kwalletmanager_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kwalletmanager_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 kwalletmanager_LDADD   = $(LIB_KIO) -lkwalletclient
 METASOURCES = AUTO
 noinst_HEADERS = kwalletmanager.h kwalletpopup.h walletwidget.h kwalleteditor.h\
diff --git a/superkaramba/src/Makefile.am b/superkaramba/src/Makefile.am
index a01bbc0..14c38e7 100644
--- a/superkaramba/src/Makefile.am
+++ b/superkaramba/src/Makefile.am
@@ -40,7 +40,7 @@ superkaramba_SOURCES = main.cpp karamba.cpp meter.cpp bar.cpp sensor.cpp \
 
 # kde_cfg_DATA = superkaramba.kcfg
 
-superkaramba_LDFLAGS = -Wl,-export-dynamic  $(KDE_RPATH) $(all_libraries) $(PYTHONLIB) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+superkaramba_LDFLAGS = -Wl,-export-dynamic  $(KDE_RPATH) $(all_libraries) $(PYTHONLIB) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 #superkaramba_LDADD = -lkio $(LIB_KDEUI) $(LIBPYTHON) $(LIBKVM) $(MY_LIBKNEWSTUFF)
 superkaramba_LDADD = -lkio $(LIB_KDEUI) $(LIBPYTHON) $(LIBKVM) $(MY_LIBKNEWSTUFF)
 
diff --git a/kdessh/kdessh.cpp b/kdessh/kdessh.cpp
index 438aa33..a3d5003 100644
--- a/kdessh/kdessh.cpp
+++ b/kdessh/kdessh.cpp
@@ -2,7 +2,7 @@
  *
  * $Id$
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
  */
 
@@ -27,9 +27,9 @@
 #include <kcmdlineargs.h>
 #include <kmessagebox.h>
 
-#include <kdesu/ssh.h>
-#include <kdesu/client.h>
-#include <kdesu/defaults.h>
+#include <tdesu/ssh.h>
+#include <tdesu/client.h>
+#include <tdesu/defaults.h>
 
 #include "sshdlg.h"
 
@@ -38,7 +38,7 @@ static KCmdLineOptions options[] =
     { "+host", I18N_NOOP("Specifies the remote host"), 0 },
     { "+command", I18N_NOOP("The command to run"), 0 },
     { "u <user>", I18N_NOOP("Specifies the target uid"), 0 },
-    { "s <path>", I18N_NOOP("Specify remote stub location"), "kdesu_stub" },
+    { "s <path>", I18N_NOOP("Specify remote stub location"), "tdesu_stub" },
     { "n", I18N_NOOP("Do not keep password"), 0 },
     { "q", I18N_NOOP("Stop the daemon (forgets all passwords)"), 0 },
     { "t", I18N_NOOP("Enable terminal output (no password keeping)"), 0 },
@@ -128,7 +128,7 @@ int main(int argc, char *argv[])
 	have_daemon = false;
     }
 
-    // Try to exec the command with kdesud?
+    // Try to exec the command with tdesud?
     bool keep = !args->isSet("n") && have_daemon;
     bool terminal = args->isSet("t");
     if (keep && !terminal)
@@ -2,7 +2,7 @@
  * $Id$
  *
- * This file is part of the KDE project, module kdesu.
+ * This file is part of the KDE project, module tdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
  */
diff --git a/kdessh/sshdlg.cpp b/kdessh/sshdlg.cpp
index 49f4e52..62dcd24 100644
--- a/kdessh/sshdlg.cpp
+++ b/kdessh/sshdlg.cpp
@@ -2,14 +2,14 @@
  *
  * $Id$
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
  */
 
 #include <klocale.h>
 #include <kmessagebox.h>
 
-#include <kdesu/ssh.h>
+#include <tdesu/ssh.h>
 #include "sshdlg.h"
 
 
@@ -59,7 +59,7 @@ bool KDEsshDialog::checkPassword(const char *password)
 
     case SshProcess::SshNotFound:
 	KMessageBox::sorry(this,
-		i18n("The programs 'ssh' or 'kdesu_stub' cannot be found.\n"
+		i18n("The programs 'ssh' or 'tdesu_stub' cannot be found.\n"
 		"Make sure your PATH is set correctly."));
 	done(Rejected);
 	return false;
@@ -2,14 +2,14 @@
  * $Id$
  *
- * This file is part of the KDE project, module kdesu.
+ * This file is part of the KDE project, module tdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
  */
-- 
cgit v1.2.3

